@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Counter;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.018';
+our $VERSION   = '0.019';
 
 use Sub::HandlesVia::HandlerLibrary;
 our @ISA = 'Sub::HandlesVia::HandlerLibrary';
@@ -39,6 +39,14 @@ sub set {
 		template  => '« $ARG »',
 		usage     => '$value',
 		documentation => 'Sets the counter to the given value.',
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 0 );\n",
+				"  \$object->$method\( 5 );\n",
+				"  say \$object->$attr; ## ==> 5\n",
+				"\n";
+		},
 }
 
 sub inc {
@@ -51,6 +59,17 @@ sub inc {
 		lvalue_template => '$GET += (#ARG ? $ARG : 1)',
 		usage     => '$amount?',
 		documentation => 'Increments the counter by C<< $amount >>, or by 1 if no value is given.',
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 0 );\n",
+				"  \$object->$method;\n",
+				"  \$object->$method;\n",
+				"  say \$object->$attr; ## ==> 2\n",
+				"  \$object->$method( 3 );\n",
+				"  say \$object->$attr; ## ==> 5\n",
+				"\n";
+		},
 }
 
 sub dec {
@@ -63,6 +82,17 @@ sub dec {
 		lvalue_template => '$GET -= (#ARG ? $ARG : 1)',
 		usage     => '$amount?',
 		documentation => 'Decrements the counter by C<< $amount >>, or by 1 if no value is given.',
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 10 );\n",
+				"  \$object->$method;\n",
+				"  \$object->$method;\n",
+				"  say \$object->$attr; ## ==> 8\n",
+				"  \$object->$method( 5 );\n",
+				"  say \$object->$attr; ## ==> 3\n",
+				"\n";
+		},
 }
 
 sub reset {
@@ -72,6 +102,14 @@ sub reset {
 		template  => '« $DEFAULT »',
 		default_for_reset => sub { 0 },
 		documentation => 'Sets the counter to its default value, or 0 if it has no default.',
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 10 );\n",
+				"  \$object->$method;\n",
+				"  say \$object->$attr; ## ==> 0\n",
+				"\n";
+		},
 }
 
 1;
\ No newline at end of file
