@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Number;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.018';
+our $VERSION   = '0.019';
 
 use Sub::HandlesVia::HandlerLibrary;
 our @ISA = 'Sub::HandlesVia::HandlerLibrary';
@@ -35,6 +35,14 @@ sub set {
 		lvalue_template => '$GET = $ARG',
 		usage => '$value',
 		documentation => "Sets the number to a new value.",
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 4 );\n",
+				"  \$object->$method\( 5 );\n",
+				"  say \$object->$attr; ## ==> 5\n",
+				"\n";
+		},
 }
 
 sub get {
@@ -43,6 +51,13 @@ sub get {
 		args      => 0,
 		template  => '$GET',
 		documentation => "Returns the current value of the number.",
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 4 );\n",
+				"  say \$object->$method; ## ==> 4\n",
+				"\n";
+		},
 }
 
 sub add {
@@ -53,6 +68,14 @@ sub add {
 		template  => '« $GET + $ARG »',
 		usage     => '$addend',
 		documentation => "Adds a number to the existing number, updating the attribute.",
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 4 );\n",
+				"  \$object->$method( 5 );\n",
+				"  say \$object->$attr; ## ==> 9\n",
+				"\n";
+		},
 }
 
 sub sub {
@@ -63,6 +86,14 @@ sub sub {
 		template  => '« $GET - $ARG »',
 		usage     => '$subtrahend',
 		documentation => "Subtracts a number from the existing number, updating the attribute.",
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 9 );\n",
+				"  \$object->$method( 6 );\n",
+				"  say \$object->$attr; ## ==> 3\n",
+				"\n";
+		},
 }
 
 sub mul {
@@ -73,6 +104,14 @@ sub mul {
 		template  => '« $GET * $ARG »',
 		usage     => '$factor',
 		documentation => "Multiplies the existing number by a number, updating the attribute.",
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 2 );\n",
+				"  \$object->$method( 5 );\n",
+				"  say \$object->$attr; ## ==> 10\n",
+				"\n";
+		},
 }
 
 sub div {
@@ -83,6 +122,14 @@ sub div {
 		template  => '« $GET / $ARG »',
 		usage     => '$divisor',
 		documentation => "Divides the existing number by a number, updating the attribute.",
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 5 );\n",
+				"  \$object->$method( 2 );\n",
+				"  say \$object->$attr; ## ==> 3\n",
+				"\n";
+		},
 }
 
 sub mod {
@@ -93,6 +140,14 @@ sub mod {
 		template  => '« $GET % $ARG »',
 		usage     => '$divisor',
 		documentation => "Finds the current number modulo a divisor, updating the attribute.",
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => 5 );\n",
+				"  \$object->$method( 2 );\n",
+				"  say \$object->$attr; ## ==> 1\n",
+				"\n";
+		},
 }
 
 sub abs {
@@ -102,6 +157,14 @@ sub abs {
 		template  => '« abs($GET) »',
 		additional_validation => 'no incoming values',
 		documentation => "Finds the absolute value of the current number, updating the attribute.",
+		_examples => sub {
+			my ( $class, $attr, $method ) = @_;
+			return join "",
+				"  my \$object = $class\->new( $attr => -5 );\n",
+				"  \$object->$method;\n",
+				"  say \$object->$attr; ## ==> 5\n",
+				"\n";
+		},
 }
 
 for my $comparison ( qw/ cmp eq ne lt gt le ge / ) {
